@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 15.2 Debian package creator
-# Release 2018-11-14
+# DaVinci Resolve 15.2.1 Debian package creator
+# Release 2018-11-29
 # By Daniel Tufvesson
 #
 
@@ -97,7 +97,7 @@ extract_zip() {
 }
 
 # Setup variables
-RESOLVE_VERSION=15.2
+RESOLVE_VERSION=15.2.1
 DEB_STEPPING=1
 case $1 in
     studio)
@@ -239,10 +239,6 @@ Conflicts: ${DEB_CONFLICTS}
 EOF
 cat > ${DEB_DIR}/DEBIAN/postinst <<EOF
 #!/bin/sh
-test -e /usr/lib/x86_64-linux-gnu/libcrypto.so.1.0.0 && ln -sf /usr/lib/x86_64-linux-gnu/libcrypto.so.1.0.0 /opt/resolve/libs/libcrypto.so.10
-test -e /lib/x86_64-linux-gnu/libcrypto.so.1.0.0 && ln -sf /lib/x86_64-linux-gnu/libcrypto.so.1.0.0 /opt/resolve/libs/libcrypto.so.10
-test -e /usr/lib/x86_64-linux-gnu/libssl.so.1.0.0 && ln -sf /usr/lib/x86_64-linux-gnu/libssl.so.1.0.0 /opt/resolve/libs/libssl.so.10
-test -e /lib/x86_64-linux-gnu/libssl.so.1.0.0 && ln -sf /lib/x86_64-linux-gnu/libssl.so.1.0.0 /opt/resolve/libs/libssl.so.10
 test -e /opt/resolve/configs/config.dat || cp /opt/resolve/configs/config.dat-pkg-default /opt/resolve/configs/config.dat
 test -e /opt/resolve/configs/log-conf.xml || cp /opt/resolve/configs/log-conf.xml-pkg-default /opt/resolve/configs/log-conf.xml
 test -e /opt/resolve/DolbyVision/config.bin || cp /opt/resolve/DolbyVision/config.bin-pkg-default /opt/resolve/DolbyVision/config.bin
@@ -260,12 +256,6 @@ chmod -R a+rw /opt/resolve/.crashreport
 chmod -R a+rw /opt/resolve/logs
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
-cat > ${DEB_DIR}/DEBIAN/prerm <<EOF
-#!/bin/sh
-rm -f /opt/resolve/libs/libcrypto.so.10
-rm -f /opt/resolve/libs/libssl.so.10
-EOF
-make_executable ${DEB_DIR}/DEBIAN/prerm
 check_command fakeroot
 check_command dpkg-deb
 fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb
